==> react-native-hotqa-sdk-0.2.3.tgz: package/src/components/fill-in-the-blank/index.js <==
import React, {useState, useEffect} from 'react';
import {StyleSheet, View, TextInput, Text, ScrollView} from 'react-native';
import {onConfigurations} from '../../common/helper';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import {Dropdown} from 'react-native-material-dropdown';

FontAwesome.loadFont();

export default (props) => {
  const {item, dispatch, isFinish, audio, user_answer} = props;
  const configurations = JSON.parse(item.configurations);
  const dataCorrect = configurations.data[0];
  const dataQuestion = configurations.paragraph_sections[0];
  const dataSelect = configurations.correct_answer[0];
  // dataSelect.sort();

  const dataSelectNew = [];
  let dataAnswer = [];

  dataSelect.forEach((i) => {
    const newItem = {value: i, answer: ''};
    dataSelectNew.push(newItem);
    dataAnswer.push('');
  });
  // console.log(25, isFinish, user_answer);
  if (isFinish && user_answer.length > 0) {
    user_answer.forEach((answer) => {
      if (item.id === answer.question_id) {
        if (Array.isArray(answer.user_answer.value)) {
          dataAnswer = answer.user_answer.value[0];
        }
      }
    });
  }

  const [data, setData] = useState(dataAnswer);

  const setDataAnswer = (answer, index) => {
    audio();
    data[index] = answer;
    onConfigurations(item, data, dispatch);
  };

  const replaceText = (item) => {
    const replace1 = item.replace('*', '').replace('\n', '');
    return replace1;
  };

  return (
    <View style={[styles.configView]}>
      <ScrollView contentContainerStyle={styles.containerScroll}>
        {dataQuestion.map((item, index) => {
          // console.log(51, item);
          return (
            <View style={styles.containerQues} key={index}>
              <Text style={styles.txtContent}>{replaceText(item)}</Text>
              {item.includes('(') && (
                <View style={{flexDirection: 'row', alignItems: 'center'}}>
                  <View style={styles.viewDropdown}>
                    <Dropdown
                      disabled={isFinish}
                      style={{alignItems: 'center'}}
                      containerStyle={styles.contentStyle}
                      inputContainerStyle={{borderBottomWidth: 0}}
                      pickerStyle={{top: '20%', left: '30%', width: '60%'}}
                      labelHeight={0}
                      data={dataSelectNew}
                      rippleOpacity={0}
                      baseColor="orange"
                      renderAccessory={() => null}
                      onChangeText={(value) => setDataAnswer(value, index)}
                      value={dataAnswer[index]}
                      renderBase={({value}) => {
                        return (
                          <Text style={styles.text}>
                            <Text>{value}</Text>
                          </Text>
                        );
                      }}
                    />
                  </View>
                </View>
              )}
            </View>
          );
        })}
      </ScrollView>
      {isFinish && (
        <Text style={[styles.txtAnswer, {marginTop: 100, marginBottom: 10}]}>
          Đáp án
        </Text>
      )}
      {isFinish && (
        <ScrollView>
          {dataSelect.map((answer, index) => {
            return (
              <Text style={[styles.txtAnswer]} key={index}>
                {`(${index + 1}) ` + answer}
              </Text>
            );
          })}
        </ScrollView>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  configView: {
    flexWrap: 'wrap',
    // width: '100%',
    // minHeight: 200,
    marginEnd: 20,
    alignItems: 'center',
  },
  containerScroll: {
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
  containerQues: {
    flexDirection: 'row',
    marginVertical: 5,
    flexWrap: 'wrap',
    alignItems: 'center',
  },
  textInput: {
    color: 'black',
    fontSize: 16,
    textAlign: 'center',
    minWidth: 80,
    paddingVertical: 6,
    borderColor: '#F5A237',
    borderRadius: 12,
    borderWidth: 1,
    marginHorizontal: 5,
    paddingHorizontal: 8,
    // backgroundColor: '#D7E9FF',
  },
  viewTextType2: {
    minWidth: 80,
    fontSize: 14,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    color: 'red',
    textAlign: 'center',
  },
  viewBorder: {
    minWidth: 80,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    alignItems: 'center',
  },
  viewDropdown: {
    marginHorizontal: 8,
    borderColor: '#F5A237',
    borderWidth: 1,
    paddingHorizontal: 8,
    borderRadius: 20,
    justifyContent: 'center',
  },
  contentStyle: {
    height: 30,
    minWidth: 80,
    paddingTop: 2,
  },
  text: {
    textAlign: 'center',
    color: 'black',
    fontSize: 16,
    marginTop: 2,
  },
  txtContent: {
    fontSize: 16,
    lineHeight: 24,
  },
  txtAnswer: {
    color: 'red',
    fontSize: 18,
    marginTop: 4,
    lineHeight: 28,
  },
});

==> react-native-hotqa-sdk-0.2.4.tgz: package/src/components/fill-in-the-blank/index.js <==
import React, {useState, useEffect} from 'react';
import {StyleSheet, View, TextInput, Text, ScrollView} from 'react-native';
import {onConfigurations} from '../../common/helper';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import {Dropdown} from 'react-native-material-dropdown';

FontAwesome.loadFont();

export default (props) => {
  const {item, dispatch, isFinish, audio, user_answer} = props;
  const configurations = JSON.parse(item.configurations);
  // const dataCorrect = configurations.data[0];
  const dataQuestion = configurations.paragraph_sections[0];
  const dataSelect = configurations.correct_answer[0];

  const dataSelectNew = [];
  let dataAnswer = [];

  dataSelect.forEach((i) => {
    const newItem = {value: i, answer: ''};
    dataSelectNew.push(newItem);
    dataAnswer.push('');
  });

  dataSelectNew.sort((a, b) => {
    const x = a.value;
    const y = b.value;
    if (x < y) {
      return -1;
    }
    if (x > y) {
      return 1;
    }
    return 0;
  });

  // console.log(25, isFinish, user_answer);
  if (isFinish && user_answer.length > 0) {
    user_answer.forEach((answer) => {
      if (item.id === answer.question_id) {
        if (Array.isArray(answer.user_answer.value)) {
          dataAnswer = answer.user_answer.value[0];
        }
      }
    });
  }

  const [data, setData] = useState(dataAnswer);

  const setDataAnswer = (questions, answer, index) => {
    audio();
    data[index] = answer;
    onConfigurations(questions, data, dispatch);
  };

  const replaceText = (item) => {
    const replace1 = item.replace('*', '').replace('\n', '');
    return replace1;
  };

  return (
    <View style={[styles.configView]}>
      <ScrollView contentContainerStyle={styles.containerScroll}>
        {dataQuestion.map((question, index) => {
          // console.log(51, item);
          return (
            <View style={styles.containerQues} key={index}>
              <Text style={styles.txtContent}>{replaceText(question)}</Text>
              {question.includes('(') && (
                <View style={{flexDirection: 'row', alignItems: 'center'}}>
                  <View style={styles.viewDropdown}>
                    <Dropdown
                      disabled={isFinish}
                      style={{alignItems: 'center'}}
                      containerStyle={styles.contentStyle}
                      inputContainerStyle={{borderBottomWidth: 0}}
                      pickerStyle={{top: '20%', left: '30%', width: '60%'}}
                      labelHeight={0}
                      data={dataSelectNew}
                      rippleOpacity={0}
                      baseColor="orange"
                      renderAccessory={() => null}
                      onChangeText={(value) =>
                        setDataAnswer(item, value, index)
                      }
                      value={dataAnswer[index]}
                      renderBase={({value}) => {
                        return (
                          <Text style={styles.text}>
                            <Text>{value}</Text>
                          </Text>
                        );
                      }}
                    />
                  </View>
                </View>
              )}
            </View>
          );
        })}
      </ScrollView>
      {isFinish && (
        <Text style={[styles.txtAnswer, {marginTop: 100, marginBottom: 10}]}>
          Đáp án
        </Text>
      )}
      {isFinish && (
        <ScrollView>
          {dataSelect.map((answer, index) => {
            return (
              <Text style={[styles.txtAnswer]} key={index}>
                {`(${index + 1}) ` + answer}
              </Text>
            );
          })}
        </ScrollView>
      )}
    </View>
  );
};

const styles = StyleSheet.create({
  configView: {
    flexWrap: 'wrap',
    // width: '100%',
    // minHeight: 200,
    marginEnd: 20,
    alignItems: 'center',
  },
  containerScroll: {
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
  containerQues: {
    flexDirection: 'row',
    marginVertical: 5,
    flexWrap: 'wrap',
    alignItems: 'center',
  },
  textInput: {
    color: 'black',
    fontSize: 16,
    textAlign: 'center',
    minWidth: 80,
    paddingVertical: 6,
    borderColor: '#F5A237',
    borderRadius: 12,
    borderWidth: 1,
    marginHorizontal: 5,
    paddingHorizontal: 8,
    // backgroundColor: '#D7E9FF',
  },
  viewTextType2: {
    minWidth: 80,
    fontSize: 14,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    color: 'red',
    textAlign: 'center',
  },
  viewBorder: {
    minWidth: 80,
    borderColor: '#F5A237',
    padding: 8,
    paddingVertical: 6,
    borderWidth: 1,
    borderRadius: 15,
    marginHorizontal: 5,
    alignItems: 'center',
  },
  viewDropdown: {
    marginHorizontal: 8,
    borderColor: '#F5A237',
    borderWidth: 1,
    paddingHorizontal: 8,
    borderRadius: 20,
    justifyContent: 'center',
  },
  contentStyle: {
    height: 30,
    minWidth: 80,
    paddingTop: 2,
  },
  text: {
    textAlign: 'center',
    color: 'black',
    fontSize: 16,
    marginTop: 2,
  },
  txtContent: {
    fontSize: 16,
    lineHeight: 24,
  },
  txtAnswer: {
    color: 'red',
    fontSize: 18,
    marginTop: 4,
    lineHeight: 28,
  },
});
